#
# spec file for package slv2
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           slv2
Version:        0.6.6
Release:        3.3
Summary:        A library to make the use of LV2 plugins as simple as possible

Group:          Productivity/Multimedia/Sound/Utilities
License:        GPLv2+
Url:            http://drobilla.net/software/slv2/
Source0:        http://download.drobilla.net/%{name}-%{version}.tar.bz2
# This patch removes the file hosts/jack_compat.h and reference to it in hosts/lv2_jack_host.c
# See drobillad bug tracker #630 at http://dev.drobilla.net/ticket/630
# Patch (and these comments) can be removed in the next release.
Patch0:         slv2-0.6.6-licencefix.patch
# PATCH-FIX-UPSTREAM slv2-fix_redland_require_in_pkgconfig.patch http://dev.drobilla.net/ticket/776 pascal.bleser@opensuse.org -- fix the slv2.pc file by adding "Requires: redland" rather than hard-coding the redland libs and includes into the .pc file, the latter possibly causing build failures
# See drobillad bug tracker #776 at http://dev.drobilla.net/ticket/776
Patch1:         slv2-fix_redland_require_in_pkgconfig.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       curl
Requires:       ladspa
# This is an attempt to prevent a mix of openSUSE and packman packages which are at the same version.
Requires:       libslv2-9 = %{version}-%{release}
BuildRequires:  doxygen gcc-c++ graphviz ladspa-devel pkg-config python-base xorg-x11-util-devel
BuildRequires:  curl-devel
BuildRequires:  libraptor-devel >= 1.4.12
BuildRequires:  librasqal-devel >= 0.9.11
BuildRequires:  libxml2-devel >= 2.4.0
BuildRequires:  libxslt-devel >= 1.0.18
BuildRequires:  zlib-devel
%if 0%{?suse_version} > 1120
BuildRequires:  pkgconfig(jack) >= 0.109 pkgconfig(lv2core) pkgconfig(redland)
%else
BuildRequires:  libjack-devel >= 0.109 libredland-devel lv2core-devel
%endif

%description
SLV2 is a library to make the use of LV2 plugins as simple as
possible for applications. SLV2 is free software (GPL v2 or later)
written in C99 using the Redland RDF toolkit, and is known to work
on GNU/Linux and Mac OS X.

%package        -n libslv2-9
Summary:        Library for %{name}
Group:          System/Libraries

%description    -n libslv2-9
The lib%{name}-9 package contains the %{name} library.


%package        devel
Summary:        Libraries, includes etc to develop with the slv2 library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Requires:       curl-devel
Requires:       libjack-devel
Requires:       libraptor-devel
Requires:       librasqal-devel
Requires:       libredland-devel
Requires:       libxml2-devel
Requires:       libxslt-devel
# This is an attempt to prevent a mix of openSUSE and packman packages which are at the same version.
Provides:       libslv2-devel = %{version}-%{release}
Obsoletes:      libslv2-devel < %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
chmod 0644 %{S:0}
%setup -q
# fix .pc.in file by using "Requires: redland" rather than hard-coding the includes and libs of redland into it
# http://dev.drobilla.net/ticket/776
%patch1

# This patch removes the file hosts/jack_compat.h and reference to it in hosts/lv2_jack_host.c
# See drobillad bug tracker #630 at http://dev.drobilla.net/ticket/630
# Patch (and these comments) can be removed in the next release.
%patch0
# This wasn't necessary until I enabled docs and test then it couldn't find rdf.h and rascal.h but then waf install stopped installing datadir in /usr/r.
pushd src
#lndir %{_includedir}/redland/
#lndir %{_includedir}/rasqal/rasqal/
popd

%build
# let's find out which raptor.pc we have first
if pkg-config --exists raptor2; then
    raptor=raptor2
elif pkg-config --exists raptor; then
    raptor=raptor
else
    echo "ERROR: neither raptor2.pc nor raptor.pc found" >&2
    exit 1
fi

# let's check here first:
for p in $raptor rasqal redland; do
    pkg-config --exists --print-errors "$p" || { echo "ERROR: missing ${p}.pc" >&2; exit 1; }
done

export CFLAGS="%{optflags} -fPIC -ggdb `pkg-config --cflags redland $raptor rasqal`"
export CXXFLAGS="$CFLAGS"
export LINKFLAGS="%{optflags} `pkg-config --libs $raptor rasqal redland`"

# We can pass LINKFLAGS through environment variables, but we cannot influence where
# they're used, and they are put before -lslv2, which causes link order optimizations
# to result in undefined symbols.
# Hence, we need to set SUSE_ASNEEDED=0 to disable link order optimization:
export SUSE_ASNEEDED=0

./waf -vv \
  --prefix="%{_prefix}" \
  --libdir="%{_libdir}" \
  --build-docs \
  --htmldir="%{_docdir}/%{name}" \
  --test \
  configure

# waf only understands -j, so do not use smp_mflags
./waf -vv build %{?jobs:-j%jobs}

%install
./waf -vv install --destdir="%{buildroot}"
find "%{buildroot}" -type f -name '*.la' -exec rm -f {} ';'
# This was needed untill I enabled docs and test. See prep section.
#cp -vr %%{buildroot}%%{_prefix}/r/* %%{buildroot}%%{_prefix}/
#rm -rf %%{buildroot}%%{_prefix}/r

for f in README AUTHORS COPYING ChangeLog; do
    %__install -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$f"
done

%__rm -f "%{buildroot}%{_docdir}/%{name}"/*.{html,css,js,png,gif}

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%post -n libslv2-9 -p /sbin/ldconfig

%postun -n libslv2-9 -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/README
%doc %{_docdir}/%{name}/AUTHORS
%doc %{_docdir}/%{name}/COPYING
%doc %{_docdir}/%{name}/ChangeLog
%{_bindir}/lv2_inspect
%{_bindir}/lv2_jack_host
%{_bindir}/lv2_list
%{_bindir}/lv2_simple_jack_host
%{_mandir}/man1/*

%files -n libslv2-9
%defattr(-,root,root,-)
%{_libdir}/libslv2.so.9
%{_libdir}/libslv2.so.9.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/libslv2.so
%{_libdir}/pkgconfig/slv2.pc
%{_mandir}/man3/*

%changelog
* Tue Oct  4 2011 pascal.bleser@opensuse.org
- disable link order optimization (see spec file for details)
- explicitly pass the compiler and linker flags of the redland
  dependencies (raptor2 and rasqal) to fix the build
* Mon Oct  3 2011 pascal.bleser@opensuse.org
- add slv2-fix_redland_require_in_pkgconfig.patch to fix the .pc file to have a
  Requires on redland, rather than hard-coding the redland includes and libs
  into the .pc file; sent upstream as http://dev.drobilla.net/ticket/776
* Sun Apr 24 2011 toddrme2178@gmail.com
- Add 32bit compatibility libraries
* Thu Feb  3 2011 davejplater@gmail.com
- Created slv2-0.6.6-licencefix.patch to remove hosts/jack_compat.h
  and reference to it. See drobillad bug tracker #630
* Fri Jan 14 2011 davejplater@gmail.com
- Created package slv2-0.6.6 to enable ardour and other packages to
  use LV2 plugins.
